*
		+---------------------------------------------------------------------------------------------------------------------------------------------+ 
		| Name:			HAC_Template.sas																											  |		
		|																																			  |		
		| Description:	Hospital-Acquired Complications (HAC) Grouper according to criteria and categories                                            |
		|				established by the Australian Commission on Safety and Quality in Health Care (ACSQHC).                                       |
        |               For more information regarding the criteria please visit                                                                      |
        |               www.safetyandquality.gov.au/our-work/information-strategy/indicators/hospital-acquired-complications/                         |
        |                                                                                                                                             |
		|				This grouper calculates the number of occurences for each HAC. 														    	  |
		|				For more information relating to the output variables please see supporting documentation.                                    |
		|																																			  |
		| Version:		up to 3.1																													  |
		|																																			  |		
		| Authors:		Jada Ching										                                                                              |
		|				Jessica Skoog									                                                                              |
		|				Independent Hospital Pricing Authority																						  |	
		|             																																  |	
		| Date:			July 2022	                                                                       											  |
		+---------------------------------------------------------------------------------------------------------------------------------------------+
;

*===========================================================================;
*Stage 0: Choose grouper version											;
*===========================================================================;

	%let GRPV = 031 ;						* current options are: 010,011,020,030,031 ;

*===========================================================================;
*Stage 1: Set out relevant input and output datasets;
*===========================================================================;

	%let LOCATION = C:\Data\&grpv. maps ;

*Input dataset;

	%let INPUT = HAC_INPUT ;

*Output dataset;	
	%let OUTPUT = HAC_OUTPUT ;

*===========================================================================;
*Stage 2: Set prefix for diagnosis codes, procedure codes and onset flags	;
*===========================================================================;
											* Required Format ;
*Prefix for Procedure Array ;
	%let PROC_PREFIX = x11srg ;				* Character Format 'NNNNNNN' ;
											* Either 07,08,09,10,11 or 12;
*Prefix for Diagnosis Array ;
	%let DIAG_PREFIX = x11ddx ; 			* Character Format ANN{N[N]} ;
											* Either 07,08,09,10,11 or 12 ;
*Prefix for Onset Array ;
	%let ONSET_PREFIX = onset ; 			* Character Format
												'1' = Condition with onset during the episode of admitted patient care
												'2' = Condition not noted as arising during the episode of admitted patient care 
												'9' = Not reported ;

	%let DRG = AN100DRG ; 
	%let ICD = ICD10AM ;					* currently only ICD10AM ;
	%let &icd._Edition = 12 ;				* Either 07,08,09,10,11 or 12 ;
	
*===========================================================================;
*Stage 3: Episode Characteristics											;
*===========================================================================;
											* METeOR ID ;			* Required Format ;
	%let ADMMODE = admm ;  					* 269976x ;	 			* Integer ;
	%let CARE_TYPE = care ; 				* 491557 ;				* Decimal e.g. 7.1 ;
	%let ADM_DATE = adm_date ;				* 695137 ;				* Date ;
	%let SEP_DATE = sep_date ;				* 270025 ;				* Date ;
	%let LEAVE = leave ;					* 270251 ;				* Integer ;
	%let QLDAYS = qldays ;					* 270033 ;				* Integer ;

*===========================================================================;
*Stage 4: Mental Health Options (for grouper versions 3.1 onwards)			;
*===========================================================================;

* Choose options for Mental Health Cohort ;
	%let MentalH_option = 1 ;				* Option 0: does not create cohorts ;
											* Option 1: creates 3 individual flags that have overlap (recommended) ;
											* Option 2: creates 1 variable with 3 mutually exclusive cohorts, noting that ;
														* cohort 1 is a subset of cohort 3, and ;
														* cohort 2 is a subset of cohort 1 ;
* Choose option here (1 or 2) ;
	%let Age_option = 1 ;

* Option 1: use birthdate and admission date to determine patient age (slower) ;
	%let BIR_DATE = bir_date ;				* 287007 ;				* Date ;

* Option 2: provide patient age variable (faster) ;
	%let AGE = age ;

*===========================================================================;
*Stage 5: Run HAC grouper													;
*===========================================================================;

%include "&location.\Hospital Acquired Complication Grouper &grpv..sas" ;
